@@ -5,11 +5,11 @@ import json
 import os
 import tempfile
 from collections import namedtuple
+from unittest import TestCase
 
 from mock import (
     ANY,
     DEFAULT,
-    Mock,
     patch,
 )
 from requests import Response
@@ -21,10 +21,10 @@ from click_toolbelt.constants import (
 from click_toolbelt.register import (
     Register,
 )
-from click_toolbelt.tests.test_common import BaseClickToolbeltCommandTestCase
+from click_toolbelt.tests.test_common import ClickToolbeltCommandBaseTestCase
 
 
-class BaseRegisterCommandTestCase(BaseClickToolbeltCommandTestCase):
+class BaseRegisterCommandTestCase(ClickToolbeltCommandBaseTestCase, TestCase):
     command_class = Register
 
     def setUp(self):
@@ -39,98 +39,6 @@ class BaseRegisterCommandTestCase(BaseClickToolbeltCommandTestCase):
         self.addCleanup(patcher.stop)
 
 
-class UploadFilesTestCase(BaseRegisterCommandTestCase):
-
-    def setUp(self):
-        super(UploadFilesTestCase, self).setUp()
-
-        name = 'click_toolbelt.common.ClickToolbeltCommand.get_oauth_session'
-        patcher = patch(name)
-        mock_session = patcher.start()
-        self.mock_post = mock_session.return_value.post
-        self.addCleanup(patcher.stop)
-
-        self.binary_file = self.get_temporary_file()
-
-    def test_upload_files(self):
-        mock_response = self.mock_post.return_value
-        mock_response.ok = True
-        mock_response.json.return_value = {
-            'successful': True,
-            'upload_id': 'some-valid-upload-id',
-        }
-
-        response = self.command.upload_files(self.binary_file.name)
-        self.assertEqual(response, {
-            'success': True,
-            'errors': [],
-            'upload_id': 'some-valid-upload-id',
-            'binary_filesize': os.path.getsize(self.binary_file.name),
-            'source_uploaded': False,
-        })
-
-    def test_upload_files_uses_environment_variables(self):
-        with patch.dict(os.environ,
-                        CLICK_UPDOWN_UPLOAD_URL='http://example.com'):
-            upload_url = 'http://example.com/unscanned-upload/'
-            self.command.upload_files(self.binary_file.name)
-            self.mock_post.assert_called_once_with(
-                upload_url, files={'binary': ANY})
-
-    def test_upload_files_with_source_upload(self):
-        mock_response = self.mock_post.return_value
-        mock_response.ok = True
-        mock_response.json.return_value = {
-            'successful': True,
-            'upload_id': 'some-valid-upload-id',
-        }
-
-        source_file = self.get_temporary_file()
-        response = self.command.upload_files(self.binary_file.name,
-                                             source_file.name)
-        self.assertEqual(response, {
-            'success': True,
-            'errors': [],
-            'upload_id': 'some-valid-upload-id',
-            'binary_filesize': os.path.getsize(self.binary_file.name),
-            'source_uploaded': True,
-        })
-
-    @patch('click_toolbelt.register.Register.get_oauth_session')
-    def test_upload_files_with_invalid_oauth_session(self,
-                                                     mock_get_oauth_session):
-        mock_get_oauth_session.return_value = None
-        response = self.command.upload_files(self.binary_file.name)
-        self.assertEqual(response, {
-            'success': False,
-            'errors': ['No valid credentials found.'],
-        })
-        self.assertFalse(self.mock_post.called)
-
-    def test_upload_files_error_response(self):
-        mock_response = self.mock_post.return_value
-        mock_response.ok = False
-        mock_response.reason = '500 INTERNAL SERVER ERROR'
-        mock_response.text = 'server failed'
-
-        response = self.command.upload_files(self.binary_file.name)
-        self.assertEqual(response, {
-            'success': False,
-            'errors': ['server failed'],
-        })
-
-    def test_upload_files_handle_malformed_response(self):
-        mock_response = self.mock_post.return_value
-        mock_response.json.return_value = {'successful': False}
-
-        response = self.command.upload_files(self.binary_file.name)
-        err = KeyError('upload_id')
-        self.assertEqual(response, {
-            'success': False,
-            'errors': [str(err)],
-        })
-
-
 class RegisterAppTestCase(BaseRegisterCommandTestCase):
 
     def setUp(self):
@@ -150,7 +58,7 @@ class RegisterAppTestCase(BaseRegisterCommandTestCase):
         }
 
         patcher = patch.multiple(
-            'click_toolbelt.register',
+            'click_toolbelt.common',
             SCAN_STATUS_POLL_DELAY=0.0001)
         patcher.start()
         self.addCleanup(patcher.stop)
@@ -367,7 +275,7 @@ class RegisterAppTestCase(BaseRegisterCommandTestCase):
             files=[],
         )
 
-    @patch('click_toolbelt.register.open')
+    @patch('click_toolbelt.common.open')
     def test_register_app_with_icon(self, mock_open):
         with tempfile.NamedTemporaryFile() as icon:
             mock_open.return_value = icon
@@ -389,7 +297,7 @@ class RegisterAppTestCase(BaseRegisterCommandTestCase):
                 ],
             )
 
-    @patch('click_toolbelt.register.open')
+    @patch('click_toolbelt.common.open')
     def test_register_app_with_screenshots(self, mock_open):
         screenshot1 = tempfile.NamedTemporaryFile()
         screenshot2 = tempfile.NamedTemporaryFile()
